# Generated by Django 4.2.7 on 2023-12-01 15:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0004_alter_infosources_display_index_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="infosources",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="infosources",
            index=models.Index(fields=["name"], name="edc_next_ap_name_543d65_idx"),
        ),
    ]
