# Generated by Django 4.2.7 on 2023-12-01 15:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_next_appointment",
            "0003_remove_infosources_edc_next_ap_id_0fdae6_idx_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="infosources",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="infosources",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
    ]
