# Generated by Django 4.2.7 on 2023-12-01 23:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0005_alter_infosources_name_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="infosources",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Information Source",
                "verbose_name_plural": "Information Sources",
            },
        ),
    ]
