# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0006_alter_infosources_options"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="infosources",
            name="edc_next_ap_name_543d65_idx",
        ),
    ]
