# Generated by Django 4.2.7 on 2023-12-01 15:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0002_infosources_extra_value"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="infosources",
            name="edc_next_ap_id_0fdae6_idx",
        ),
        migrations.AddIndex(
            model_name="infosources",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_next_ap_display_4e292d_idx",
            ),
        ),
    ]
